@@ -166,6 +166,7 @@ struct option options[] = {
   { "tape", 0, NULL, 1000 + hw_tape },
   { "vbe", 0, NULL, 1000 + hw_vbe },
   { "bluetooth", 0, NULL, 1000 + hw_bluetooth },
+  { "fingerprint", 0, NULL, 1000 + hw_fingerprint },
   { "all", 0, NULL, 2000 },
   { "reallyall", 0, NULL, 2001 },
   { "smp", 0, NULL, 2002 },
@@ -306,7 +307,6 @@ int main(int argc, char **argv)
           break;
 
         case 317:
-          hd_data->flags.nowpa = 1;
           break;
 
         case 318:
