@@ -7,11 +7,12 @@
 #include "hddb.h"
 #include "isapnp.h"
 
-
-/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
- * isapnp stuff
+/**
+ * @defgroup ISAPnPint ISA PnP
+ * @ingroup libhdBUSint
+ * @brief ISA PnP scan functions
  *
- * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+ * @{
  */
 
 #if defined(__i386__) || defined(__alpha__)
@@ -115,39 +116,33 @@ void get_pnp_devs(hd_data_t *hd_data)
   hd_t *hd;
   char *s, *t, buf[4];
   unsigned u1, u2, u3;
+  str_list_t *sf_bus, *sf_bus_e;
+  char *sf_dev, *sf_dev2;
 
-  struct sysfs_bus *sf_bus;
-  struct dlist *sf_dev_list;
-  struct sysfs_device *sf_dev;
-  struct sysfs_device *sf_dev_2;
-
-  sf_bus = sysfs_open_bus("pnp");
+  sf_bus = reverse_str_list(read_dir("/sys/bus/pnp/devices", 'l'));
 
   if(!sf_bus) {
     ADD2LOG("sysfs: no such bus: pnp\n");
     return;
   }
 
-  sf_dev_list = sysfs_get_bus_devices(sf_bus);
+  for(sf_bus_e = sf_bus; sf_bus_e; sf_bus_e = sf_bus_e->next) {
+    sf_dev = new_str(hd_read_sysfs_link("/sys/bus/pnp/devices", sf_bus_e->str));
 
-
-  if(sf_dev_list) dlist_for_each_data(sf_dev_list, sf_dev, struct sysfs_device) {
     ADD2LOG(
-      "  pnp device: name = %s, bus_id = %s, bus = %s\n    path = %s\n",
-      sf_dev->name,
-      sf_dev->bus_id,
-      sf_dev->bus,
-      hd_sysfs_id(sf_dev->path)
+      "  pnp device: name = %s\n    path = %s\n",
+      sf_bus_e->str,
+      hd_sysfs_id(sf_dev)
     );
 
-    if((s = hd_attr_str(sysfs_get_device_attr(sf_dev, "id")))) {
+    if((s = get_sysfs_attr_by_path(sf_dev, "id"))) {
       if(sscanf(s, "%3s%4x", buf, &u1) == 2 && (u2 = name2eisa_id(buf))) {
         ADD2LOG("    id = %s %04x\n", eisa_vendor_str(u2), u1);
 
         hd = add_hd_entry(hd_data, __LINE__, 0);
 
-        hd->sysfs_id = new_str(hd_sysfs_id(sf_dev->path));
-        hd->sysfs_bus_id = new_str(sf_dev->bus_id);
+        hd->sysfs_id = new_str(hd_sysfs_id(sf_dev));
+        hd->sysfs_bus_id = new_str(sf_bus_e->str);
 
         hd->bus.id = bus_isa;
         hd->is.isapnp = 1;
@@ -160,44 +155,36 @@ void get_pnp_devs(hd_data_t *hd_data)
           hd->func = u3;
         }
 
-        s = new_str(sf_dev->path);
-        if((t = strrchr(s, '/'))) *t = 0;
+        sf_dev2 = new_str(sf_dev);
+        if((t = strrchr(sf_dev2, '/'))) *t = 0;
 
-        sf_dev_2 = sysfs_open_device_path(s);
-        if(sf_dev_2) {
-          if((t = hd_attr_str(sysfs_get_device_attr(sf_dev_2, "card_id")))) {
-            if(sscanf(t, "%3s%4x", buf, &u1) == 2 && (u2 = name2eisa_id(buf))) {
-              ADD2LOG("    card id = %s %04x\n", eisa_vendor_str(u2), u1);
+        if((t = get_sysfs_attr_by_path(sf_dev2, "card_id"))) {
+          if(sscanf(t, "%3s%4x", buf, &u1) == 2 && (u2 = name2eisa_id(buf))) {
+            ADD2LOG("    card id = %s %04x\n", eisa_vendor_str(u2), u1);
 
-              hd->vendor.id = u2;
-              hd->device.id = MAKE_ID(TAG_EISA, u1);
-            }
+            hd->vendor.id = u2;
+            hd->device.id = MAKE_ID(TAG_EISA, u1);
           }
-          if((t = hd_attr_str(sysfs_get_device_attr(sf_dev_2, "name")))) {
-             hd->device.name = canon_str(t, strlen(t));
-             if(!strcasecmp(hd->device.name, "unknown")) {
-               hd->device.name = free_mem(hd->device.name);
-             }
-          }
-
-          sysfs_close_device(sf_dev_2);
+        }
+        if((t = get_sysfs_attr_by_path(sf_dev2, "name"))) {
+           hd->device.name = canon_str(t, strlen(t));
+           if(!strcasecmp(hd->device.name, "unknown")) {
+             hd->device.name = free_mem(hd->device.name);
+           }
         }
 
-
-        free_mem(s);
-
+        free_mem(sf_dev2);
 
         if(hd->sub_vendor.id == hd->vendor.id && hd->sub_device.id == hd->device.id) {
           hd->sub_vendor.id = hd->sub_device.id = 0;
         }
-
       }
     }
 
+    free_mem(sf_dev);
   }
 
-
-  sysfs_close_bus(sf_bus);
+  free_str_list(sf_bus);
 
 }
 
@@ -436,3 +423,5 @@ void build_list(hd_data_t *hd_data, str_list_t *isapnp_list)
 
 #endif /* defined(__i386__) || defined(__alpha__) */
 
+/** @} **/
+
