@@ -40,7 +40,6 @@ static void add_mv(hd_data_t *hdata);
 static void add_iseries(hd_data_t *hdata);
 static void add_uml(hd_data_t *hdata);
 static void add_kma(hd_data_t *hdata);
-static void add_xen(hd_data_t *hdata);
 static void add_if_name(hd_t *hd_card, hd_t *hd);
 
 /*
@@ -50,10 +49,10 @@ static void add_if_name(hd_t *hd_card, hd_t *hd);
 void hd_scan_net(hd_data_t *hd_data)
 {
   unsigned u;
-  int if_type;
+  int if_type, if_carrier;
   hd_t *hd, *hd_card;
   char *s, *hw_addr;
-  hd_res_t *res, *res1;
+  hd_res_t *res, *res1, *res2;
   uint64_t ul0;
   str_list_t *sf_class, *sf_class_e;
   char *sf_cdev = NULL, *sf_dev = NULL;
@@ -69,7 +68,8 @@ void hd_scan_net(hd_data_t *hd_data)
 
   PROGRESS(1, 0, "get network data");
 
-  sf_class = reverse_str_list(read_dir("/sys/class/net", 'd'));
+  sf_class = reverse_str_list(read_dir("/sys/class/net", 'l'));
+  if(!sf_class) sf_class = reverse_str_list(read_dir("/sys/class/net", 'd'));
 
   if(!sf_class) {
     ADD2LOG("sysfs: no such class: net\n");
@@ -93,6 +93,12 @@ void hd_scan_net(hd_data_t *hd_data)
       ADD2LOG("    type = %d\n", if_type);
     }
 
+    if_carrier = -1;
+    if(hd_attr_uint(get_sysfs_attr_by_path(sf_cdev, "carrier"), &ul0, 0)) {
+      if_carrier = ul0;
+      ADD2LOG("    carrier = %d\n", if_carrier);
+    }
+
     hw_addr = NULL;
     if((s = get_sysfs_attr_by_path(sf_cdev, "address"))) {
       hw_addr = canon_str(s, strlen(s));
@@ -128,7 +134,13 @@ void hd_scan_net(hd_data_t *hd_data)
       add_res_entry(&hd->res, res1);
     }
 
-    hw_addr = free_mem(hw_addr);
+    res2 = NULL;
+    if(if_carrier >= 0) {
+      res = new_mem(sizeof *res);
+      res->link.type = res_link;
+      res->link.state = if_carrier ? 1 : 0;
+      add_res_entry(&hd->res, res);
+    }
 
     hd->unix_dev_name = new_str(sf_class_e->str);
     hd->sysfs_id = new_str(hd_sysfs_id(sf_cdev));
@@ -140,6 +152,8 @@ void hd_scan_net(hd_data_t *hd_data)
       get_driverinfo(hd_data, hd);
     }
 
+    hd_card = NULL;
+
     if(sf_dev) {
       hd->sysfs_device_link = new_str(hd_sysfs_id(sf_dev)); 
 
@@ -174,6 +188,29 @@ void hd_scan_net(hd_data_t *hd_data)
       }
     }
 
+    if(!hd_card && hw_addr) {
+      /* try to find card based on hwaddr (for prom-based cards) */
+
+      for(hd_card = hd_data->hd; hd_card; hd_card = hd_card->next) {
+        if(
+          hd_card->base_class.id != bc_network ||
+          hd_card->sub_class.id != 0
+        ) continue;
+        for(res = hd_card->res; res; res = res->next) {
+          if(
+            res->any.type == res_hwaddr &&
+            !strcmp(hw_addr, res->hwaddr.addr)
+          ) break;
+        }
+        if(res) {
+          hd->attached_to = hd_card->idx;
+          break;
+        }
+      }
+    }
+
+    hw_addr = free_mem(hw_addr);
+
 #if 0
     "ctc"	sc_nif_ctc
     "iucv"	sc_nif_iucv
@@ -297,7 +334,6 @@ void hd_scan_net(hd_data_t *hd_data)
   if(hd_is_sgi_altix(hd_data)) add_xpnet(hd_data);
   if(hd_is_iseries(hd_data)) add_iseries(hd_data);
   add_uml(hd_data);
-  add_xen(hd_data);
   add_kma(hd_data);
   add_mv(hd_data);
 
@@ -307,7 +343,11 @@ void hd_scan_net(hd_data_t *hd_data)
       hd->module == hd_data->module &&
       hd->base_class.id == bc_network_interface
     ) {
-      get_linkstate(hd_data, hd);
+      for(res = hd->res; res; res = res->next) {
+        if(res->any.type == res_link) break;
+      }
+
+      if(!res) get_linkstate(hd_data, hd);
 
       if(!(hd_card = hd_get_device_by_idx(hd_data, hd->attached_to))) continue;
 
@@ -686,54 +726,6 @@ void add_kma(hd_data_t *hd_data)
 }
 
 
-/*
- * XEN veth devices.
- */
-void add_xen(hd_data_t *hd_data)
-{
-  hd_t *hd, *hd_card;
-  hd_res_t *res, *res2;
-  unsigned card_cnt = 0;
-  char *s = NULL;
-  struct stat sbuf;
-
-  for(hd = hd_data->hd ; hd; hd = hd->next) {
-    if(
-      hd->module == hd_data->module &&
-      hd->base_class.id == bc_network_interface
-    ) {
-      str_printf(&s, 0, "/proc/xen/net/%s", hd->unix_dev_name);
-      if(stat(s, &sbuf) || !S_ISDIR(sbuf.st_mode)) continue;
-
-      hd_card = add_hd_entry(hd_data, __LINE__, 0);
-      hd_card->base_class.id = bc_network;
-      hd_card->sub_class.id = 0x00;
-      hd_card->vendor.id = MAKE_ID(TAG_SPECIAL, 0x6011);	// Xen
-      hd_card->device.id = MAKE_ID(TAG_SPECIAL, 0x0001);
-      hd_card->slot = card_cnt++;
-      str_printf(&hd_card->device.name, 0, "Virtual Ethernet card %d", hd_card->slot);
-
-      hd->attached_to = hd_card->idx;
-
-      for(res = hd->res; res; res = res->next) {
-        if(res->any.type == res_hwaddr) break;
-      }
-
-      if(res) {
-        res2 = new_mem(sizeof *res2);
-        res2->hwaddr.type = res_hwaddr;
-        res2->hwaddr.addr = new_str(res->hwaddr.addr);
-        add_res_entry(&hd_card->res, res2);
-      }
-
-      add_if_name(hd_card, hd);
-    }
-  }
-
-  free_mem(s);
-}
-
-
 /*
  * add interface name to card
  */
