@@ -572,6 +572,14 @@ void add_input_dev(hd_data_t *hd_data, char *name)
           dev_num.minor = 63;
           hd->unix_dev_name = new_str(DEV_MICE);
           hd->unix_dev_num = dev_num;
+
+          // make it a mouse, #216091
+          if(hd->base_class.id == bc_none) {
+            hd->base_class.id = bc_mouse;
+            hd->sub_class.id = sc_mou_usb;
+            hd->compat_vendor.id = MAKE_ID(TAG_SPECIAL, 0x0200);
+            hd->compat_device.id = MAKE_ID(TAG_SPECIAL, 0x001);
+          }
         }
       }
     }
@@ -810,7 +818,7 @@ void get_serial_devs(hd_data_t *hd_data)
   for(sf_class_e = sf_class; sf_class_e; sf_class_e = sf_class_e->next) {
     if(strncmp(sf_class_e->str, "ttyUSB", 6)) continue;
 
-    str_printf(&sf_cdev, 0, "/sys/class/usb/%s", sf_class_e->str);
+    str_printf(&sf_cdev, 0, "/sys/class/tty/%s", sf_class_e->str);
 
     ADD2LOG(
       "  usb: name = %s, path = %s\n",
